﻿<#Get status of Windows Services in Excel Table#>

#Create object of the Excel.Application
$Excel = New-Object -comobject Excel.Application 

#Make this instance visible
$Excel.visible = $True

#Create Excel Workbook
$ExcelWB = $Excel.Workbooks.Add() 

#Create 1 Excel Worksheet
$ExcelWS = $ExcelWB.Worksheets.Item(1) 

#Define Report Title 
$ExcelWS.Cells.Item(1,1) = "Services Status Report"
$ExcelWS.Range("A1","B1").Cells.Merge()

#Create Header for the table
#Name and Width of the first column in the table
$ExcelWS.Cells.Item(2,1) = "Services Name"
$ExcelWS.Cells.Item(2,1).ColumnWidth = 30 

#Name and Width of the second column in the table
$ExcelWS.Cells.Item(2,2) = "Service Status" 
$ExcelWS.Cells.Item(2,2).ColumnWidth = 15

#cell background, font color, and boldness of the header
$ExcelWS.Range("A2","B2").Interior.ColorIndex = 41 
$ExcelWS.Range("A2","B2").Font.ColorIndex = 2 
$ExcelWS.Range("A2","B2").Font.Bold = $True 


$row = 3

ForEach($Service in Get-Service)
{
    #Fill the rows with services information
    $ExcelWS.Cells.Item($row,1) = $Service.DisplayName
    $ExcelWS.Cells.Item($row,2) = $Service.Status.ToString()

    
    #Change font color Green/Red according to service status
    if($Service.Status -eq "Running")
        {
            $ExcelWS.Cells.Item($row,1).Font.ColorIndex = 10
            $ExcelWS.Cells.Item($row,2).Font.ColorIndex = 10
        }
    Elseif($Service.Status -eq "Stopped")
        {
            $ExcelWS.Cells.Item($row,1).Font.ColorIndex = 3
            $ExcelWS.Cells.Item($row,2).Font.ColorIndex = 3
        }
        

  $row++  
}

#Table Column Autofit
$ExcelWS.UsedRange.EntireColumn.AutoFit()

#Save Exvel Sheet
$ExcelWS.SaveAs("D:\ServicesStatusReport.xlsx")

#Quit Excel
$Excel.Quit()            